==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/data-google-compute-backend-service.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleComputeBackendServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service#name DataGoogleComputeBackendService#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service#project DataGoogleComputeBackendService#project}.
     *
     * @stability stable
     */
    readonly project?: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceBackend extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get balancingMode(): string;
    /**
     * @stability stable
     */
    get capacityScaler(): number;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    get maxConnections(): number;
    /**
     * @stability stable
     */
    get maxConnectionsPerEndpoint(): number;
    /**
     * @stability stable
     */
    get maxConnectionsPerInstance(): number;
    /**
     * @stability stable
     */
    get maxRate(): number;
    /**
     * @stability stable
     */
    get maxRatePerEndpoint(): number;
    /**
     * @stability stable
     */
    get maxRatePerInstance(): number;
    /**
     * @stability stable
     */
    get maxUtilization(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceCdnPolicyCacheKeyPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get includeHost(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get includeProtocol(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get includeQueryString(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get queryStringBlacklist(): string[];
    /**
     * @stability stable
     */
    get queryStringWhitelist(): string[];
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceCdnPolicyNegativeCachingPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get code(): number;
    /**
     * @stability stable
     */
    get ttl(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceCdnPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get cacheKeyPolicy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get cacheMode(): string;
    /**
     * @stability stable
     */
    get clientTtl(): number;
    /**
     * @stability stable
     */
    get defaultTtl(): number;
    /**
     * @stability stable
     */
    get maxTtl(): number;
    /**
     * @stability stable
     */
    get negativeCaching(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get negativeCachingPolicy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get serveWhileStale(): number;
    /**
     * @stability stable
     */
    get signedUrlCacheMaxAgeSec(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceCircuitBreakers extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get maxConnections(): number;
    /**
     * @stability stable
     */
    get maxPendingRequests(): number;
    /**
     * @stability stable
     */
    get maxRequests(): number;
    /**
     * @stability stable
     */
    get maxRequestsPerConnection(): number;
    /**
     * @stability stable
     */
    get maxRetries(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceConsistentHashHttpCookieTtl extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get nanos(): number;
    /**
     * @stability stable
     */
    get seconds(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceConsistentHashHttpCookie extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    get ttl(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceConsistentHash extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get httpCookie(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get httpHeaderName(): string;
    /**
     * @stability stable
     */
    get minimumRingSize(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceIap extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get oauth2ClientId(): string;
    /**
     * @stability stable
     */
    get oauth2ClientSecret(): string;
    /**
     * @stability stable
     */
    get oauth2ClientSecretSha256(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceLogConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enable(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get sampleRate(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceOutlierDetectionBaseEjectionTime extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get nanos(): number;
    /**
     * @stability stable
     */
    get seconds(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceOutlierDetectionInterval extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get nanos(): number;
    /**
     * @stability stable
     */
    get seconds(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeBackendServiceOutlierDetection extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get baseEjectionTime(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get consecutiveErrors(): number;
    /**
     * @stability stable
     */
    get consecutiveGatewayFailure(): number;
    /**
     * @stability stable
     */
    get enforcingConsecutiveErrors(): number;
    /**
     * @stability stable
     */
    get enforcingConsecutiveGatewayFailure(): number;
    /**
     * @stability stable
     */
    get enforcingSuccessRate(): number;
    /**
     * @stability stable
     */
    get interval(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get maxEjectionPercent(): number;
    /**
     * @stability stable
     */
    get successRateMinimumHosts(): number;
    /**
     * @stability stable
     */
    get successRateRequestVolume(): number;
    /**
     * @stability stable
     */
    get successRateStdevFactor(): number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service google_compute_backend_service}.
 *
 * @stability stable
 */
export declare class DataGoogleComputeBackendService extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service google_compute_backend_service} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleComputeBackendServiceConfig);
    /**
     * @stability stable
     */
    get affinityCookieTtlSec(): number;
    /**
     * @stability stable
     */
    backend(index: string): DataGoogleComputeBackendServiceBackend;
    /**
     * @stability stable
     */
    cdnPolicy(index: string): DataGoogleComputeBackendServiceCdnPolicy;
    /**
     * @stability stable
     */
    circuitBreakers(index: string): DataGoogleComputeBackendServiceCircuitBreakers;
    /**
     * @stability stable
     */
    get connectionDrainingTimeoutSec(): number;
    /**
     * @stability stable
     */
    consistentHash(index: string): DataGoogleComputeBackendServiceConsistentHash;
    /**
     * @stability stable
     */
    get creationTimestamp(): string;
    /**
     * @stability stable
     */
    get customRequestHeaders(): string[];
    /**
     * @stability stable
     */
    get customResponseHeaders(): string[];
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get enableCdn(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get fingerprint(): string;
    /**
     * @stability stable
     */
    get healthChecks(): string[];
    /**
     * @stability stable
     */
    iap(index: string): DataGoogleComputeBackendServiceIap;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get loadBalancingScheme(): string;
    /**
     * @stability stable
     */
    get localityLbPolicy(): string;
    /**
     * @stability stable
     */
    logConfig(index: string): DataGoogleComputeBackendServiceLogConfig;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    outlierDetection(index: string): DataGoogleComputeBackendServiceOutlierDetection;
    /**
     * @stability stable
     */
    get portName(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    get securityPolicy(): string;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    get sessionAffinity(): string;
    /**
     * @stability stable
     */
    get timeoutSec(): number;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.39.tar.gz: package/lib/data-google-compute-backend-service.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleComputeBackendServiceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service#name DataGoogleComputeBackendService#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service#project DataGoogleComputeBackendService#project}
    */
    readonly project?: string;
}
export declare class DataGoogleComputeBackendServiceBackend extends cdktf.ComplexComputedList {
    get balancingMode(): string;
    get capacityScaler(): number;
    get description(): string;
    get group(): string;
    get maxConnections(): number;
    get maxConnectionsPerEndpoint(): number;
    get maxConnectionsPerInstance(): number;
    get maxRate(): number;
    get maxRatePerEndpoint(): number;
    get maxRatePerInstance(): number;
    get maxUtilization(): number;
}
export declare class DataGoogleComputeBackendServiceCdnPolicyCacheKeyPolicy extends cdktf.ComplexComputedList {
    get includeHost(): cdktf.IResolvable;
    get includeProtocol(): cdktf.IResolvable;
    get includeQueryString(): cdktf.IResolvable;
    get queryStringBlacklist(): string[];
    get queryStringWhitelist(): string[];
}
export declare class DataGoogleComputeBackendServiceCdnPolicyNegativeCachingPolicy extends cdktf.ComplexComputedList {
    get code(): number;
    get ttl(): number;
}
export declare class DataGoogleComputeBackendServiceCdnPolicy extends cdktf.ComplexComputedList {
    get cacheKeyPolicy(): cdktf.IResolvable;
    get cacheMode(): string;
    get clientTtl(): number;
    get defaultTtl(): number;
    get maxTtl(): number;
    get negativeCaching(): cdktf.IResolvable;
    get negativeCachingPolicy(): cdktf.IResolvable;
    get serveWhileStale(): number;
    get signedUrlCacheMaxAgeSec(): number;
}
export declare class DataGoogleComputeBackendServiceCircuitBreakers extends cdktf.ComplexComputedList {
    get maxConnections(): number;
    get maxPendingRequests(): number;
    get maxRequests(): number;
    get maxRequestsPerConnection(): number;
    get maxRetries(): number;
}
export declare class DataGoogleComputeBackendServiceConsistentHashHttpCookieTtl extends cdktf.ComplexComputedList {
    get nanos(): number;
    get seconds(): number;
}
export declare class DataGoogleComputeBackendServiceConsistentHashHttpCookie extends cdktf.ComplexComputedList {
    get name(): string;
    get path(): string;
    get ttl(): cdktf.IResolvable;
}
export declare class DataGoogleComputeBackendServiceConsistentHash extends cdktf.ComplexComputedList {
    get httpCookie(): cdktf.IResolvable;
    get httpHeaderName(): string;
    get minimumRingSize(): number;
}
export declare class DataGoogleComputeBackendServiceIap extends cdktf.ComplexComputedList {
    get oauth2ClientId(): string;
    get oauth2ClientSecret(): string;
    get oauth2ClientSecretSha256(): string;
}
export declare class DataGoogleComputeBackendServiceLogConfig extends cdktf.ComplexComputedList {
    get enable(): cdktf.IResolvable;
    get sampleRate(): number;
}
export declare class DataGoogleComputeBackendServiceOutlierDetectionBaseEjectionTime extends cdktf.ComplexComputedList {
    get nanos(): number;
    get seconds(): number;
}
export declare class DataGoogleComputeBackendServiceOutlierDetectionInterval extends cdktf.ComplexComputedList {
    get nanos(): number;
    get seconds(): number;
}
export declare class DataGoogleComputeBackendServiceOutlierDetection extends cdktf.ComplexComputedList {
    get baseEjectionTime(): cdktf.IResolvable;
    get consecutiveErrors(): number;
    get consecutiveGatewayFailure(): number;
    get enforcingConsecutiveErrors(): number;
    get enforcingConsecutiveGatewayFailure(): number;
    get enforcingSuccessRate(): number;
    get interval(): cdktf.IResolvable;
    get maxEjectionPercent(): number;
    get successRateMinimumHosts(): number;
    get successRateRequestVolume(): number;
    get successRateStdevFactor(): number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service google_compute_backend_service}
*/
export declare class DataGoogleComputeBackendService extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_backend_service google_compute_backend_service} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleComputeBackendServiceConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleComputeBackendServiceConfig);
    get affinityCookieTtlSec(): number;
    backend(index: string): DataGoogleComputeBackendServiceBackend;
    cdnPolicy(index: string): DataGoogleComputeBackendServiceCdnPolicy;
    circuitBreakers(index: string): DataGoogleComputeBackendServiceCircuitBreakers;
    get connectionDrainingTimeoutSec(): number;
    consistentHash(index: string): DataGoogleComputeBackendServiceConsistentHash;
    get creationTimestamp(): string;
    get customRequestHeaders(): string[];
    get customResponseHeaders(): string[];
    get description(): string;
    get enableCdn(): cdktf.IResolvable;
    get fingerprint(): string;
    get healthChecks(): string[];
    iap(index: string): DataGoogleComputeBackendServiceIap;
    get id(): string;
    get loadBalancingScheme(): string;
    get localityLbPolicy(): string;
    logConfig(index: string): DataGoogleComputeBackendServiceLogConfig;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    outlierDetection(index: string): DataGoogleComputeBackendServiceOutlierDetection;
    get portName(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get protocol(): string;
    get securityPolicy(): string;
    get selfLink(): string;
    get sessionAffinity(): string;
    get timeoutSec(): number;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
